@@ -1,4 +1,6 @@
-/*
+/* ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
+ *
  * The contents of this file are subject to the Mozilla Public
  * License Version 1.1 (the "MPL"); you may not use this file
  * except in compliance with the MPL. You may obtain a copy of
@@ -11,41 +13,37 @@
  *
  * The Original Code is Enigmail.
  *
- * The Initial Developer of this code is Patrick Brunschwig.
- * Portions created by Patrick Brunschwig <patrick.brunschwig@gmx.net>
- * are Copyright (C) 2004-2005 Patrick Brunschwig.
- * All Rights Reserved.
+ * The Initial Developer of the Original Code is Patrick Brunschwig.
+ * Portions created by Patrick Brunschwig <patrick@enigmail.net> are
+ * Copyright (C) 2004 Patrick Brunschwig. All Rights Reserved.
  *
  * Contributor(s):
  *
- * Alternatively, the contents of this file may be used under the
- * terms of the GNU General Public License (the "GPL"), in which case
- * the provisions of the GPL are applicable instead of
- * those above. If you wish to allow use of your version of this
- * file only under the terms of the GPL and not to allow
- * others to use your version of this file under the MPL, indicate
- * your decision by deleting the provisions above and replace them
- * with the notice and other provisions required by the GPL.
- * If you do not delete the provisions above, a recipient
- * may use your version of this file under either the MPL or the
- * GPL.
- */
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
+ * ***** END LICENSE BLOCK ***** */
 
 // Uses: chrome://enigmail/content/enigmailCommon.js
 
-// Initialize enigmailCommon
-EnigInitCommon("enigmailSearchKey");
+Components.utils.import("resource://enigmail/enigmailCommon.jsm");
+const Ec = EnigmailCommon;
 
 const INPUT = 0;
 const RESULT = 1;
 
 const ENIG_DEFAULT_HKP_PORT  = "11371";
+const ENIG_DEFAULT_HKPS_PORT  = "443";
 const ENIG_DEFAULT_LDAP_PORT = "389";
 
-const ENIG_IMG_NOT_SELECTED = "chrome://enigmail/content/check0.png";
-const ENIG_IMG_SELECTED     = "chrome://enigmail/content/check1.png";
-const ENIG_IMG_DISABLED     = "chrome://enigmail/content/check2.png";
-
 const ENIG_CONN_TYPE_HTTP    = 1;
 const ENIG_CONN_TYPE_GPGKEYS = 2;
 
@@ -55,6 +53,10 @@ const KEY_INVALID="i";
 const KEY_DISABLED="d";
 const KEY_NOT_VALID=KEY_EXPIRED+KEY_REVOKED+KEY_INVALID+KEY_DISABLED;
 
+var gErrorData = "";
+var gOutputData = "";
+var gEnigRequest;
+
 function trim(str) {
   return str.replace(/^(\s*)(.*)/, "$2").replace(/\s+$/,"");
 }
@@ -65,11 +67,8 @@ function onLoad () {
 
   var keyserver = window.arguments[INPUT].keyserver;
   var protocol="";
-  if (keyserver.search(/[a-zA-Z0-9\-\_\.]+:\/\//)==0) {
+  if (keyserver.search(/^[a-zA-Z0-9\-\_\.]+:\/\//)==0) {
     protocol=keyserver.replace(/^([a-zA-Z0-9\-\_\.]+)(:\/\/.*)/, "$1");
-    if (protocol.search(/hkp/i) >= 0) {
-      protocol="hkp";
-    }
     keyserver=keyserver.replace(/^[a-zA-Z0-9\-\_\.]+:\/\//, "");
   }
   else {
@@ -81,44 +80,47 @@ function onLoad () {
   case "hkp":
     port = ENIG_DEFAULT_HKP_PORT;
     break;
+  case "hkps":
+    port = ENIG_DEFAULT_HKPS_PORT;
+    break;
   case "ldap":
     port = ENIG_DEFAULT_LDAP_PORT;
     break;
   }
-  
+
   var m = keyserver.match(/^(.+)(:)(\d+)$/);
   if (m && m.length==4) {
     keyserver = m[1];
     port = m[3];
   }
-  
-  window.enigRequest = {
+
+  gEnigRequest = {
     searchList: window.arguments[INPUT].searchList,
     keyNum: 0,
     keyserver: keyserver,
     port: port,
     protocol: protocol,
     keyList: [],
-    requestType: (EnigGetPref("useGpgKeysTool") ? ENIG_CONN_TYPE_GPGKEYS : ENIG_CONN_TYPE_HTTP),
+    requestType: (Ec.getPref("useGpgKeysTool") ? ENIG_CONN_TYPE_GPGKEYS : ENIG_CONN_TYPE_HTTP),
     gpgkeysRequest: null,
     progressMeter: document.getElementById("dialog.progress"),
     httpInProgress: false
   };
-  
-  window.enigRequest.progressMeter.mode="undetermined";
-  
+
+  gEnigRequest.progressMeter.mode="undetermined";
+
   if (window.arguments[INPUT].searchList.length == 1 &&
       window.arguments[INPUT].searchList[0].search(/^0x[A-Fa-f0-9]{8,16}$/) == 0) {
       // shrink dialog and start download if just one key ID provided
-      
-      window.enigRequest.dlKeyList = [ window.arguments[INPUT].searchList ];
+
+      gEnigRequest.dlKeyList = window.arguments[INPUT].searchList;
       document.getElementById("keySelGroup").setAttribute("collapsed", "true");
       window.sizeToContent();
       window.resizeBy(0, -320);
-      window.setTimeout(startDownload, 10);
+      Ec.dispatchEvent(startDownload, 10);
   }
   else {
-    switch (window.enigRequest.requestType) {
+    switch (gEnigRequest.requestType) {
     case ENIG_CONN_TYPE_HTTP:
       enigNewHttpRequest(nsIEnigmail.SEARCH_KEY, enigScanKeys);
       break;
@@ -132,19 +134,19 @@ function onLoad () {
 
 
 function onAccept () {
-  DEBUG_LOG("enigmailSearchKey.js: onAccept\n");
+  Ec.DEBUG_LOG("enigmailSearchKey.js: onAccept\n");
 
   var keySelList = document.getElementById("enigmailKeySel");
   var treeChildren=keySelList.getElementsByAttribute("id", "enigmailKeySelChildren")[0];
 
-  window.enigRequest.dlKeyList = [];
+  gEnigRequest.dlKeyList = [];
   var item=treeChildren.firstChild;
   while (item) {
-    var aRows = item.getElementsByAttribute("id","indicator")
+    var aRows = item.getElementsByAttribute("id","indicator");
     if (aRows.length) {
       var elem=aRows[0];
       if (elem.getAttribute("active") == "1") {
-        window.enigRequest.dlKeyList.push(item.getAttribute("id"));
+        gEnigRequest.dlKeyList.push(item.getAttribute("id"));
       }
     }
     item = item.nextSibling;
@@ -154,15 +156,15 @@ function onAccept () {
 
 
 function startDownload() {
-  DEBUG_LOG("enigmailSearchKey.js: startDownload\n");
-  if (window.enigRequest.dlKeyList.length>0) {
-    window.enigRequest.progressMeter.value = 0;
-    window.enigRequest.progressMeter.mode = "undetermined";
+  Ec.DEBUG_LOG("enigmailSearchKey.js: startDownload\n");
+  if (gEnigRequest.dlKeyList.length>0) {
+    gEnigRequest.progressMeter.value = 0;
+    gEnigRequest.progressMeter.mode = "undetermined";
     document.getElementById("progress.box").removeAttribute("hidden");
     document.getElementById("dialog.accept").setAttribute("disabled", "true");
-    window.enigRequest.keyNum = 0;
-    window.enigRequest.errorTxt="";
-    switch (window.enigRequest.requestType) {
+    gEnigRequest.keyNum = 0;
+    gEnigRequest.errorTxt="";
+    switch (gEnigRequest.requestType) {
     case ENIG_CONN_TYPE_HTTP:
       enigNewHttpRequest(nsIEnigmail.DOWNLOAD_KEY, enigImportKeys);
       break;
@@ -180,28 +182,36 @@ function startDownload() {
 
 
 function onCancel() {
-  if (window.enigRequest.httpInProgress) {
+  Ec.DEBUG_LOG("enigmailSearchKey.js: onCancel\n");
+
+  if (gEnigRequest.httpInProgress) {
     // stop download
     try {
-      if ((typeof(window.enigHttpReq) == "object") && 
+      if ((typeof(window.enigHttpReq) == "object") &&
           (window.enigHttpReq.readyState != 4)) {
           window.enigHttpReq.abort();
       }
-      window.enigRequest.httpInProgress=false;
-      if (window.enigRequest.gpgkeysRequest) {
-        enigGpgkeysCloseRequest();
-      }
+      gEnigRequest.httpInProgress=false;
     }
     catch (ex) {}
   }
+
+  if (gEnigRequest.gpgkeysRequest) {
+
+    var p = gEnigRequest.gpgkeysRequest;
+    gEnigRequest.gpgkeysRequest = null;
+    p.kill(false);
+  }
+
+  gOutputData = "";
   window.close();
 }
 
 
 function enigStatusError () {
-  DEBUG_LOG("enigmailSearchKey.js: enigStatusError\n");
-  window.enigRequest.httpInProgress=false;
-  EnigAlert(EnigGetString("noKeyserverConn", this.channel.originalURI.prePath));
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigStatusError\n");
+  gEnigRequest.httpInProgress=false;
+  Ec.alert(window, Ec.getString("noKeyserverConn", this.channel.originalURI.prePath));
   enigCloseDialog();
 }
 
@@ -211,76 +221,76 @@ function enigCloseDialog() {
 }
 
 function enigStatusLoaded (event) {
-  DEBUG_LOG("enigmailSearchKey.js: enigStatusLoaded\n");
-    
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigStatusLoaded\n");
+
   if (this.status == 200) {
     // de-HTMLize the result
     var htmlTxt = this.responseText.replace(/<([^<>]+)>/g, "");
-    
+
     this.requestCallbackFunc(ENIG_CONN_TYPE_HTTP, htmlTxt);
   }
   else if (this.status == 500 && this.statusText=="OK") {
     this.requestCallbackFunc(ENIG_CONN_TYPE_HTTP, "no keys found");
   }
   else if (this.statusText!="OK") {
-    EnigAlert(EnigGetString("keyDownloadFailed", this.statusText));
+    Ec.alert(window, Ec.getString("keyDownloadFailed", this.statusText));
     enigCloseDialog();
     return;
   }
-  
+
 }
 
 
 function enigImportKeys (connType, txt, errorTxt) {
-  DEBUG_LOG("enigmailSearchKey.js: enigImportKeys\n");
-  
-  window.enigRequest.keyNum++;
-  window.enigRequest.progressMeter.mode = "determined";
-  window.enigRequest.progressMeter.value = (100 * window.enigRequest.keyNum / window.enigRequest.dlKeyList.length).toFixed(0);
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigImportKeys\n");
+
+  gEnigRequest.keyNum++;
+  gEnigRequest.progressMeter.mode = "determined";
+  gEnigRequest.progressMeter.value = (100 * gEnigRequest.keyNum / gEnigRequest.dlKeyList.length).toFixed(0);
 
   if (txt.search(/^\[GNUPG:\] IMPORT_RES/m) < 0) {
     if (!enigImportHtmlKeys(txt)) return;
   }
   else if (errorTxt) {
-    window.enigRequest.errorTxt +=errorTxt+"\n";
+    gEnigRequest.errorTxt +=errorTxt+"\n";
   }
-  
+
   if (txt.search(/^\[GNUPG:\] IMPORT_RES/m) >= 0) {
     window.arguments[RESULT].importedKeys++;
   }
 
-  if (window.enigRequest.dlKeyList.length > window.enigRequest.keyNum) {
+  if (gEnigRequest.dlKeyList.length > gEnigRequest.keyNum) {
     switch (connType) {
       case ENIG_CONN_TYPE_HTTP:
         enigNewHttpRequest(nsIEnigmail.DOWNLOAD_KEY, window.enigHttpReq.requestCallbackFunc);
         break;
       case ENIG_CONN_TYPE_GPGKEYS:
-        enigNewGpgKeysRequest(nsIEnigmail.DOWNLOAD_KEY, window.enigRequest.callbackFunction);
+        enigNewGpgKeysRequest(nsIEnigmail.DOWNLOAD_KEY, gEnigRequest.callbackFunction);
     }
     return;
   }
-  else if (window.enigRequest.errorTxt) {
-    EnigLongAlert(window.enigRequest.errorTxt);
+  else if (gEnigRequest.errorTxt) {
+    Ec.longAlert(window, Ec.convertGpgToUnicode(gEnigRequest.errorTxt));
   }
-  
-  window.enigRequest.httpInProgress=false;
-  
+
+  gEnigRequest.httpInProgress=false;
+
   enigCloseDialog();
 }
 
 function enigImportHtmlKeys(txt) {
   var errorMsgObj = new Object();
-  
+
   var enigmailSvc = GetEnigmailSvc();
-  if (! enigmailSvc) 
+  if (! enigmailSvc)
     return false;
-  
+
   var uiFlags = nsIEnigmail.UI_ALLOW_KEY_IMPORT;
-  var r = enigmailSvc.importKey(window, uiFlags, txt, 
-                        window.enigRequest.dlKeyList[window.enigRequest.keyNum-1], 
+  var r = enigmailSvc.importKey(window, uiFlags, txt,
+                        gEnigRequest.dlKeyList[gEnigRequest.keyNum-1],
                         errorMsgObj);
   if (errorMsgObj.value)
-    EnigAlert(errorMsgObj.value);
+    Ec.alert(window, errorMsgObj.value);
   if (r == 0) {
     window.arguments[RESULT].importedKeys++;
     return true;
@@ -290,19 +300,21 @@ function enigImportHtmlKeys(txt) {
 
 
 function enigNewHttpRequest(requestType, requestCallbackFunc) {
-  DEBUG_LOG("enigmailSearchKey.js: enigNewHttpRequest\n");
-  
-  switch (window.enigRequest.protocol) {
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigNewHttpRequest\n");
+
+  switch (gEnigRequest.protocol) {
   case "hkp":
-    window.enigRequest.protocol = "http";
+    gEnigRequest.protocol = "http";
+  case "hkps":
+    gEnigRequest.protocol = "https";
   case "http":
   case "https":
     break;
   default:
-    var msg=EnigGetString("protocolNotSupported", window.enigRequest.protocol);
-    if (! EnigGetPref("useGpgKeysTool"))
-      msg += " "+EnigGetString("gpgkeysDisabled");
-    EnigAlert(msg);
+    var msg=Ec.getString("protocolNotSupported", gEnigRequest.protocol);
+    if (! Ec.getPref("useGpgKeysTool"))
+      msg += " "+Ec.getString("gpgkeysDisabled");
+    Ec.alert(window, msg);
     enigCloseDialog();
     return;
   }
@@ -311,19 +323,19 @@ function enigNewHttpRequest(requestType, requestCallbackFunc) {
   var reqCommand;
   switch (requestType) {
   case nsIEnigmail.SEARCH_KEY:
-    var pubKey = escape("<"+trim(window.enigRequest.searchList[window.enigRequest.keyNum])+">");
-    reqCommand = window.enigRequest.protocol+"://"+window.enigRequest.keyserver+":"+window.enigRequest.port+"/pks/lookup?search="+pubKey+"&op=index";
+    var pubKey = escape("<"+trim(gEnigRequest.searchList[gEnigRequest.keyNum])+">");
+    reqCommand = gEnigRequest.protocol+"://"+gEnigRequest.keyserver+":"+gEnigRequest.port+"/pks/lookup?search="+pubKey+"&op=index";
     break;
   case nsIEnigmail.DOWNLOAD_KEY:
-    var keyId = escape(trim(window.enigRequest.dlKeyList[window.enigRequest.keyNum]));
-    reqCommand = window.enigRequest.protocol+"://"+window.enigRequest.keyserver+":"+window.enigRequest.port+"/pks/lookup?search="+keyId+"&op=get";
+    var keyId = escape(trim(gEnigRequest.dlKeyList[gEnigRequest.keyNum]));
+    reqCommand = gEnigRequest.protocol+"://"+gEnigRequest.keyserver+":"+gEnigRequest.port+"/pks/lookup?search="+keyId+"&op=get";
     break;
   default:
-    EnigAlert("Unknown request type "+requestType);
+    Ec.alert(window, "Unknown request type "+requestType);
     return;
   }
 
-  window.enigRequest.httpInProgress=true;
+  gEnigRequest.httpInProgress=true;
   httpReq.open("GET", reqCommand);
   httpReq.onerror=enigStatusError;
   httpReq.onload=enigStatusLoaded;
@@ -334,11 +346,11 @@ function enigNewHttpRequest(requestType, requestCallbackFunc) {
 
 
 function enigScanKeys(connType, htmlTxt) {
-  DEBUG_LOG("enigmailSearchKey.js: enigScanKeys\n");
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigScanKeys\n");
 
-  window.enigRequest.keyNum++;
-  window.enigRequest.progressMeter.mode = "determined";
-  window.enigRequest.progressMeter.value = (100 * window.enigRequest.keyNum / window.enigRequest.searchList.length).toFixed(0);
+  gEnigRequest.keyNum++;
+  gEnigRequest.progressMeter.mode = "determined";
+  gEnigRequest.progressMeter.value = (100 * gEnigRequest.keyNum / gEnigRequest.searchList.length).toFixed(0);
 
   switch (connType) {
     case ENIG_CONN_TYPE_HTTP:
@@ -346,47 +358,47 @@ function enigScanKeys(connType, htmlTxt) {
       var domParser = new DOMParser();
       // needs improvement: result is max. 4096 bytes long!
       var htmlNode = domParser.parseFromString("<p>" + htmlTxt + "</p>", "text/xml");
-    
+
       if (htmlNode.firstChild.nodeName=="parsererror") {
-        EnigAlert("internalError");
+        Ec.alert(window, "internalError");
         return false;
       }
       enigScanHtmlKeys(htmlNode.firstChild.firstChild.data);
       break;
     case ENIG_CONN_TYPE_GPGKEYS:
-      enigScanGpgKeys(EnigConvertGpgToUnicode(unescape(htmlTxt)));
+      enigScanGpgKeys(Ec.convertGpgToUnicode(unescape(htmlTxt)));
       break;
     default:
-      ERROR_LOG("bizarre connType: "+connType+"\n");
+      Ec.ERROR_LOG("Unkonwn connType: "+connType+"\n");
   }
 
-  if (window.enigRequest.searchList.length > window.enigRequest.keyNum) {
+  if (gEnigRequest.searchList.length > gEnigRequest.keyNum) {
     switch (connType) {
       case ENIG_CONN_TYPE_HTTP:
         enigNewHttpRequest(nsIEnigmail.SEARCH_KEY, window.enigHttpReq.requestCallbackFunc);
         break;
       case  ENIG_CONN_TYPE_GPGKEYS:
-        enigNewGpgKeysRequest(nsIEnigmail.SEARCH_KEY, window.enigRequest.callbackFunction);
+        enigNewGpgKeysRequest(nsIEnigmail.SEARCH_KEY, gEnigRequest.callbackFunction);
     }
     return true;
   }
-  
-  window.enigRequest.httpInProgress=false;
-  enigPopulateList(window.enigRequest.keyList);
+
+  gEnigRequest.httpInProgress=false;
+  enigPopulateList(gEnigRequest.keyList);
   document.getElementById("progress.box").setAttribute("hidden", "true");
-  if (window.enigRequest.keyList.length == 0) {
-    EnigAlert(EnigGetString("noKeyFound"));
+  if (gEnigRequest.keyList.length == 0) {
+    Ec.alert(window, Ec.getString("noKeyFound"));
     enigCloseDialog();
   }
-  
+
   document.getElementById("dialog.accept").removeAttribute("disabled");
-  
+
   return true;
 }
 
 function enigScanHtmlKeys (txt) {
-  DEBUG_LOG("enigmailSearchKey.js: enigScanHtmlKeys\n");
-  
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigScanHtmlKeys\n");
+
   var lines=txt.split(/(\n\r|\n|\r)/);
   var key;
   for (i=0; i<lines.length; i++) {
@@ -394,7 +406,7 @@ function enigScanHtmlKeys (txt) {
       // new key
       if (key) {
         // first, append prev. key to keylist
-        window.enigRequest.keyList.push(key);
+        gEnigRequest.keyList.push(key);
       }
       key = null;
       var m=lines[i].match(/(\d+[a-zA-Z]?\/)([0-9a-fA-F]+)(\s+[\d\/\-\.]+\s+)(.*)/);
@@ -408,7 +420,7 @@ function enigScanHtmlKeys (txt) {
           if (! ignoreUid(m[4])) key.uid.push(trim(m[4]));
         }
         else if (m[4].search(/key (revoked|expired|disabled)/i)>=0) {
-          DEBUG_LOG("revoked key id "+m[4]+"\n");
+          Ec.DEBUG_LOG("revoked key id "+m[4]+"\n");
           key=null;
         }
       }
@@ -422,17 +434,18 @@ function enigScanHtmlKeys (txt) {
       }
     }
   }
-  
+
   // append prev. key to keylist
   if (key) {
-    window.enigRequest.keyList.push(key);
+    gEnigRequest.keyList.push(key);
   }
 }
 
 
 function enigScanGpgKeys(txt) {
-  DEBUG_LOG("enigmailSearchKey.js: enigScanGpgKeys\n");
-  
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigScanGpgKeys\n");
+  Ec.DEBUG_LOG("got text: "+txt+"\n");
+
   var lines=txt.split(/(\r\n|\n|\r)/);
   var outputType=0;
   var key;
@@ -454,7 +467,7 @@ function enigScanGpgKeys(txt) {
             if (! ignoreUid(m[i])) key.uid.push(trim(m[1]));
           }
           else {
-            window.enigRequest.keyList.push(key);
+            gEnigRequest.keyList.push(key);
             key=null;
           }
         }
@@ -477,7 +490,7 @@ function enigScanGpgKeys(txt) {
       m=lines[i].split(/:/);
       if (m && m.length>1 ) {
         if (key) {
-          window.enigRequest.keyList.push(key);
+          gEnigRequest.keyList.push(key);
           key=null;
         }
         dat=new Date(m[4]*1000);
@@ -499,143 +512,114 @@ function enigScanGpgKeys(txt) {
       }
     }
   }
-  
+
   // append prev. key to keylist
   if (key) {
-    window.enigRequest.keyList.push(key);
+    gEnigRequest.keyList.push(key);
   }
 }
 
 // interaction with gpgkeys_xxx
 
 function enigNewGpgKeysRequest(requestType, callbackFunction) {
-  DEBUG_LOG("enigmailSearchkey.js: enigNewGpgKeysRequest\n");
-  
+  Ec.DEBUG_LOG("enigmailSearchkey.js: enigNewGpgKeysRequest\n");
+
   var enigmailSvc = GetEnigmailSvc();
   if (!enigmailSvc) {
-    EnigAlert(EnigGetString("accessError"));
+    Ec.alert(window, Ec.getString("accessError"));
     return;
   }
-  
-  window.enigRequest.callbackFunction = callbackFunction;
-  var requestObserver = new EnigRequestObserver(enigmailGpgkeysTerminate, null);
-  var errorMsgObj = new Object();
-  var ipcRequest = null;
-  window.enigRequest.gpgkeysRequest = null;
-  
-  try {
-  
-    if (requestType == nsIEnigmail.SEARCH_KEY) {
-      var keyValue = window.enigRequest.searchList[window.enigRequest.keyNum];
+
+  gEnigRequest.callbackFunction = callbackFunction;
+  gEnigRequest.gpgkeysRequest = null;
+
+  gErrorData = "";
+  gOutputData = "";
+
+  var procListener = {
+    onStopRequest: function (exitCode) {
+      enigmailGpgkeysTerminate(exitCode);
+    },
+    onStdoutData: function(data) {
+      gOutputData += data;
+    },
+    onErrorData: function(data) {
+      gErrorData += data;
     }
-    else {
-      keyValue = window.enigRequest.dlKeyList[window.enigRequest.keyNum];
-    }
-  
-    ipcRequest = enigmailSvc.searchKey(requestType,
-                                       window.enigRequest.protocol, 
-                                       window.enigRequest.keyserver, 
-                                       window.enigRequest.port, 
-                                       keyValue,
-                                       requestObserver, 
-                                       errorMsgObj);
-  } catch (ex) {}
-  
-  if (!ipcRequest) {
+  };
+
+  if (requestType == nsIEnigmail.SEARCH_KEY) {
+    var keyValue = gEnigRequest.searchList[gEnigRequest.keyNum];
+  }
+  else {
+    keyValue = gEnigRequest.dlKeyList[gEnigRequest.keyNum];
+  }
+
+
+  var errorMsgObj = {};
+  gEnigRequest.gpgkeysRequest = Ec.searchKey(requestType,
+                                 gEnigRequest.protocol,
+                                 gEnigRequest.keyserver,
+                                 gEnigRequest.port,
+                                 keyValue,
+                                 procListener,
+                                 errorMsgObj);
+
+  if (!gEnigRequest.gpgkeysRequest) {
     // calling gpgkeys_xxx failed, let's try builtin http variant
-    switch (window.enigRequest.protocol) {
+    switch (gEnigRequest.protocol) {
     case "hkp":
     case "http":
     case "https":
-      window.enigRequest.requestType = ENIG_CONN_TYPE_HTTP;
+      gEnigRequest.requestType = ENIG_CONN_TYPE_HTTP;
       enigNewHttpRequest(requestType, enigScanKeys);
       return;
     default:
-      EnigAlert(EnigGetString("gpgKeysFailed", window.enigRequest.protocol));
+      Ec.alert(window, Ec.getString("gpgKeysFailed", gEnigRequest.protocol));
       enigCloseDialog();
       return;
     }
   }
-  
-  window.enigRequest.gpgkeysRequest = ipcRequest;
-  
-  WRITE_LOG("enigmailSearchkey.js: Start: window.enigRequest.gpgkeysRequest = "+window.enigRequest.gpgkeysRequest+"\n");
+
+  Ec.DEBUG_LOG("enigmailSearchkey.js: Start: gEnigRequest.gpgkeysRequest = "+gEnigRequest.gpgkeysRequest+"\n");
 }
 
 
+function enigmailGpgkeysTerminate(exitCode) {
+  Ec.DEBUG_LOG("enigmailSearchkey.js: Terminate: exitCode="+exitCode+"\n");
 
-function enigGpgkeysCloseRequest() {
-  DEBUG_LOG("enigmailSearchkey.js: CloseRequest\n");
-
-  if (window.enigRequest.gpgkeysRequest) {
-    try {
-      var searchkeyProcess = window.enigRequest.gpgkeysRequest.pipeTransport;
-      if (searchkeyProcess)
-        searchkeyProcess.terminate();
-    } catch(ex) {}
-
-    window.enigRequest.gpgkeysRequest.close(true);
-    window.enigRequest.gpgkeysRequest = null;
-  }
-}
-
-function enigmailGpgkeysTerminate(terminateArg, ipcRequest) {
-   DEBUG_LOG("enigmailSearchkey.js: Terminate: "+ipcRequest+"\n");
-
-   var gpgkeysRequest = window.enigRequest.gpgkeysRequest;
-   var gpgkeysProcess = gpgkeysRequest.pipeTransport;
-   var enigmailSvc = GetEnigmailSvc();
-   if (gpgkeysProcess && !gpgkeysProcess.isAttached()) {
-     gpgkeysProcess.terminate();
-     var exitCode = gpgkeysProcess.exitCode();
-     DEBUG_LOG("enigmailGpgkeysConsole: exitCode = "+exitCode+"\n");
-     if (enigmailSvc) {
-        exitCode = enigmailSvc.fixExitCode(exitCode, 0);
-     }
-   }
-
-  var console = gpgkeysRequest.stdoutConsole;
+  gEnigRequest.gpgkeysRequest = null;
 
   try {
-    console = console.QueryInterface(Components.interfaces.nsIPipeConsole);
-    var txt = null;
-    var errorTxt = null;
+    if (gErrorData.length > 0) {
+      Ec.DEBUG_LOG("enigmailSearchkey.js: Terminate(): stderr has data:\n");
+      Ec.CONSOLE_LOG(gErrorData+"\n");
+    }
 
-    if (console && console.hasNewData()) {
-      DEBUG_LOG("enigmailSearchkey.js: Terminate(): stdout.hasNewData\n");
-      txt = console.getData();
-    }
-    console = gpgkeysRequest.stderrConsole;
-    console = console.QueryInterface(Components.interfaces.nsIPipeConsole);
-    if (console && console.hasNewData()) {
-      DEBUG_LOG("enigmailSearchkey.js: Terminate(): stderr.hasNewData\n");
-      errorTxt = console.getData();
-    }
-//    gpgkeysProcess.close(true);
-    enigGpgkeysCloseRequest();
+    exitCode = Ec.fixExitCode(exitCode, 0);
 
-    if (txt) {
-      window.enigRequest.callbackFunction(ENIG_CONN_TYPE_GPGKEYS, txt, errorTxt);
+    if (gOutputData.length > 0) {
+      gEnigRequest.callbackFunction(ENIG_CONN_TYPE_GPGKEYS, gOutputData, gErrorData);
     }
-    
+
   } catch (ex) {}
 }
 
 // GUI related stuff
 
 function enigPopulateList(keyList) {
-  DEBUG_LOG("enigmailSearchKey.js: enigPopulateList\n");
-  
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigPopulateList\n");
+
   var sortUsers = function (a,b) {
      if (a.uid[0]<b.uid[0]) { return -1; } else {return 1; }
-  }
- 
+  };
+
   keyList.sort(sortUsers);
 
   var treeList = document.getElementById("enigmailKeySel");
   var treeChildren=treeList.getElementsByAttribute("id", "enigmailKeySelChildren")[0];
   var treeItem;
-  
+
   for (var i=0; i<keyList.length; i++) {
     treeItem = enigUserSelCreateRow(keyList[i].keyId, false, keyList[i].uid[0], keyList[i].created, "");
     if (keyList[i].uid.length>1) {
@@ -649,10 +633,10 @@ function enigPopulateList(keyList) {
     }
     treeChildren.appendChild(treeItem);
   }
-  
+
   if (keyList.length == 1) {
     // activate found item if just one key found
-    enigSetActive(treeItem.firstChild.firstChild, 1);
+    EnigSetActive(treeItem.firstChild.firstChild, 1);
   }
 }
 
@@ -663,7 +647,7 @@ function enigUserSelCreateRow (keyId, subKey, userId, dateField, trustStatus) {
     var userCol=document.createElement("treecell");
     userCol.setAttribute("id", "name");
     if (trustStatus.charAt(0)==KEY_EXPIRED) {
-      expCol.setAttribute("label", EnigGetString("selKeyExpired", dateField));
+      expCol.setAttribute("label", Ec.getString("selKeyExpired", dateField));
     }
     else {
       expCol.setAttribute("label", dateField);
@@ -674,14 +658,14 @@ function enigUserSelCreateRow (keyId, subKey, userId, dateField, trustStatus) {
     var keyCol=document.createElement("treecell");
     keyCol.setAttribute("id", "keyid");
     if (subKey) {
-      enigSetActive(selectCol, -1);
+      EnigSetActive(selectCol, -1);
       keyCol.setAttribute("label", "");
     }
     else  {
-      enigSetActive(selectCol, 0);
+      EnigSetActive(selectCol, 0);
       keyCol.setAttribute("label", keyId.substr(-8));
     }
-    
+
 
     var userRow=document.createElement("treerow");
     userRow.appendChild(selectCol);
@@ -695,8 +679,8 @@ function enigUserSelCreateRow (keyId, subKey, userId, dateField, trustStatus) {
 }
 
 function enigmailKeySelCallback(event) {
-  DEBUG_LOG("enigmailSearchKey.js: enigmailKeySelCallback\n");
-  
+  Ec.DEBUG_LOG("enigmailSearchKey.js: enigmailKeySelCallback\n");
+
   var Tree = document.getElementById("enigmailKeySel");
   var row = {};
   var col = {};
@@ -708,50 +692,21 @@ function enigmailKeySelCallback(event) {
 
   var treeItem = Tree.contentView.getItemAtIndex(row.value);
   Tree.currentItem=treeItem;
-  if (typeof(col.value) == "string") {
-    // mozilla <= 1.7
-    if (col.value != "selectionCol")
-      return;
-  }
-  else {
-    // mozilla >= 1.8a1
-    if (col.value.id != "selectionCol")
-      return;
-  }
-  var aRows = treeItem.getElementsByAttribute("id","indicator")
+  if (col.value.id != "selectionCol")
+    return;
+
+  var aRows = treeItem.getElementsByAttribute("id","indicator");
 
   if (aRows.length) {
     var elem=aRows[0];
     if (elem.getAttribute("active") == "1") {
-      enigSetActive(elem, 0);
+      EnigSetActive(elem, 0);
     } else if (elem.getAttribute("active") == "0") {
-      enigSetActive(elem, 1);
+      EnigSetActive(elem, 1);
     }
   }
 }
 
-// set the "active" flag and the corresponding image
-function enigSetActive(element, status) {
-
-  if (status>=0)
-    element.setAttribute("active", status.toString());
-
-  switch (status)
-  {
-  case 0:
-    element.setAttribute("src", ENIG_IMG_NOT_SELECTED);
-    break;
-  case 1:
-    element.setAttribute("src", ENIG_IMG_SELECTED);
-    break;
-  case 2:
-    element.setAttribute("src", ENIG_IMG_DISABLED);
-    break;
-  default:
-    element.setAttribute("active", -1);
-  }
-}
-
 function ignoreUid(uid) {
   const ignoreList = "{Test 555 <sdfg@gga.com>}";
   return (ignoreList.indexOf("{"+trim(uid)+"}") >= 0);
